@@ -5,7 +5,9 @@ TAR=../modello_$VERSION.orig.tar.gz
 DIR=modello-$VERSION
 TAG=modello-$2
 
-svn export https://svn.codehaus.org/modello/tags/$TAG $DIR
+mkdir -p $DIR
+tar --strip=1 -xvf $3 -C $DIR
+rm $3
 rm -rf $DIR/modello-maven-plugin
 rm -rf $DIR/modello-test
 tar -c -z -f $TAR $DIR
